@@ -25,9 +25,9 @@ def push_software(fpath, radarType, version_name):
 
     # check if can open file path
     if os.path.isfile(fpath):
-        logger.log(message="ZIP file exists for push software: " + fpath, log_level="info", to_file=True, to_terminal=True)
+        logger.log(message="ZIP file exists for push software: " + fpath, log_level="info", to_terminal=True)
     else:
-        logger.log(message="ZIP not exist for push software: " + fpath, log_level="error", to_file=True, to_terminal=True)
+        logger.log(message="ZIP not exist for push software: " + fpath, log_level="error", to_terminal=True)
         return "ZIP not exist (PS): " + fpath
         
     files = {
@@ -39,13 +39,13 @@ def push_software(fpath, radarType, version_name):
         'versionName': json.dumps(version_name)
     }
 
-    logger.log(message="Pushing software to Robin SD...", log_level="info", to_file=True, to_terminal=True)
+    logger.log(message="Pushing software to Robin SD...", log_level="info", to_terminal=True)
 
     response = requests.post(request_url + '/api/softwares/softwarefiles', headers=headers, data=values, files=files)
     if response.status_code == 200:
-        logger.log(message="Software pushed successfully!", log_level="info", to_file=True, to_terminal=True)
+        logger.log(message="Software pushed successfully!", log_level="info", to_terminal=True)
     else:
-        logger.log(message="Software push failed with status code: " + str(response.status_code), log_level="error", to_file=True, to_terminal=True)
+        logger.log(message="Software push failed with status code: " + str(response.status_code), log_level="error", to_terminal=True)
 
     try:
         response.raise_for_status()
