@@ -15,7 +15,7 @@ def zip_files(log_dir):
         zip_file = shutil.make_archive(log_dir, 'zip', log_dir)
         return zip_file
     except Exception as e:
-        logger.log(message=f"Error zipping files: {e}", to_file=True, to_terminal=True, log_level='error')
+        logger.log(message=f"Error zipping files: {e}", to_terminal=True, log_level='error')
 
 def send_slack(file_to_send, customer_name: str = None):
 
@@ -44,7 +44,7 @@ def send_slack(file_to_send, customer_name: str = None):
     except SlackApiError as e:
         # You will get a SlackApiError if "ok" is False
         assert e.response["error"]    # str like 'invalid_auth', 'channel_not_found'
-        logger.log(message=f"Slack error: {e.response['error']}", to_file=True, to_terminal=True, log_level='error')
+        logger.log(message=f"Slack error: {e.response['error']}", to_terminal=True, log_level='error')
 
 def send_slack_entrypoint():
     config = yaml_parser.parse_config()
