@@ -40,9 +40,9 @@ def arg_parser():
     args = parser.parse_args()
     config = yaml_parser.parse_config()
     # logger.log(message="Config file path: " + file_path, log_level="info", to_file=True, to_terminal=True)
-    logger.log(message="Starting Robin Radar Systems Software Uploader", log_level="info", to_file=True, to_terminal=True)
-    logger.log(message="Version: " + _version.__version__, log_level="info", to_file=True, to_terminal=True)
-    logger.log(message="Username: " + config['robin_email'], log_level="info", to_file=True, to_terminal=True)
+    logger.log(message="Starting Robin Radar Systems Software Uploader", log_level="info", to_terminal=True)
+    logger.log(message="Version: " + _version.__version__, log_level="info", to_terminal=True)
+    logger.log(message="Username: " + config['robin_email'], log_level="info", to_terminal=True)
 
     version_checker.check_latest_version()
 
@@ -52,7 +52,7 @@ def arg_parser():
 
     if args.check:
         yaml_parser.parse_config()
-        logger.log(message="All prerequisites met.", log_level="info", to_file=True, to_terminal=True)
+        logger.log(message="All prerequisites met.", log_level="info", to_terminal=True)
         sys.exit(0)
     elif args.upload:
         if radarType is None or version_name is None or upload_file_path is None:
@@ -75,7 +75,7 @@ def arg_parser():
 
     elif args.slack:
         slack_handler.send_slack_entrypoint()
-        logger.log(message="Slack message sent successfully.", log_level="info", to_file=True, to_terminal=True)
+        logger.log(message="Slack message sent successfully.", log_level="info", to_terminal=True)
         sys.exit(0)
 
     else:
