@@ -8,7 +8,7 @@ from robin_sd_upload.supportive_scripts import logger
 def remove_zip(zip_name):
     if os.path.isfile(zip_name):
         os.remove(zip_name)
-        logger.log(message="ZIP file removed: " + zip_name, log_level="info", to_file=True, to_terminal=True)
+        logger.log(message="ZIP file removed: " + zip_name, log_level="info", to_terminal=True)
     else:
-        logger.log(message="ZIP file not exist: " + zip_name, log_level="info", to_file=True, to_terminal=True)
+        logger.log(message="ZIP file not exist: " + zip_name, log_level="info", to_terminal=True)
         
\ No newline at end of file
