@@ -25,10 +25,10 @@ def check_latest_version():
     # print('latest_version is: ' + latest_version)
     # print ('package_url is: ' + package_url)
     if current_version == latest_version:
-        logger.log(message="Latest version detected, proceeding.", log_level="info", to_file=True, to_terminal=False)
+        logger.log(message="Latest version detected, proceeding.", log_level="info", to_terminal=False)
     else:
-        logger.log(message="Newer version detected, please update.", log_level="error", to_file=True, to_terminal=True)
-        logger.log(message="Current version: " + current_version, log_level="error", to_file=True, to_terminal=True)
-        logger.log(message="Latest version: " + latest_version, log_level="error", to_file=True, to_terminal=True)
-        logger.log(message="To update, run: pip3 install --upgrade " + package_name, log_level="error", to_file=True, to_terminal=True)
+        logger.log(message="Newer version detected, please update.", log_level="error", to_terminal=True)
+        logger.log(message="Current version: " + current_version, log_level="error", to_terminal=True)
+        logger.log(message="Latest version: " + latest_version, log_level="error", to_terminal=True)
+        logger.log(message="To update, run: pip3 install --upgrade " + package_name, log_level="error", to_terminal=True)
         sys.exit(1)
